document.addEventListener("DOMContentLoaded", function() {
    const soloPrivadasCheckbox = document.getElementById("soloPrivadas");
    const nasContainer = document.getElementById("nas-container");
    const nasSelect = document.getElementById("nas");
    const fechaInput = document.getElementById("fecha");
    const horaInput = document.getElementById("hora");    
    const macInput = document.getElementById("ani");
    const ipInput = document.getElementById("ip");
    const formulario = document.querySelector("form");

    // Resetear valores al cargar la página
    fechaInput.value = "";
    horaInput.value = "";
    macInput.value = "";
    ipInput.value = "";
    localStorage.removeItem("horaIngresada"); // Borra el valor almacenado
    nasSelect.value = "noexiste"; // Opción por defecto

    // Expresión regular para direcciones MAC válidas
    const macRegex = /^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$/;
    
    // Expresión regular para direcciones IP válidas (IPv4)
    const ipRegex = /^(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/;

    // Ocultar el campo NAS por defecto
    nasContainer.style.display = "none";
    nasSelect.disabled = true;

    // Deshabilitar el campo de hora por defecto
    horaInput.disabled = true;

    // Detectar cambios en el checkbox
    soloPrivadasCheckbox.addEventListener("change", function() {
        if (this.checked) {
            nasContainer.style.display = "block"; // Mostrar el campo NAS
            nasSelect.disabled = false; // Habilitar el select para enviarlo
        } else {
            nasContainer.style.display = "none"; // Ocultar el campo NAS
            nasSelect.disabled = true; // Deshabilitar el select para que no se envíe
        }
    });

    // Detectar cambios en "fecha" para habilitar "hora"
    fechaInput.addEventListener("input", function() {
        horaInput.disabled = !this.value;
    });


    // Restaurar la hora guardada en localStorage si existe
    if (localStorage.getItem("horaIngresada")) {
        horaInput.value = localStorage.getItem("horaIngresada");
        horaInput.disabled = false; // Habilitar el campo si ya había una hora guardada
    } else {
        fechaInput.value != ""; // Si tenemos una fecha habilito la hora
        horaInput.disabled = false;
    }

    // Guardar la hora en localStorage cuando el usuario cambia el valor
    horaInput.addEventListener("change", function() {
        localStorage.setItem("horaIngresada", this.value);
    });

    // Restaurar el valor guardado en localStorage si existe
    if (localStorage.getItem("horaIngresada")) {
        horaInput.value = localStorage.getItem("horaIngresada");
    }

    // Guardar el valor en localStorage cuando el usuario cambia la hora
    horaInput.addEventListener("change", function() {
        localStorage.setItem("horaIngresada", this.value);
    });

    formulario.addEventListener("submit", function(event) {
        let errores = [];

        // Validar que se ingrese una fecha obligatoriamente
        if (!fechaInput.value) {
            errores.push("Debes seleccionar una fecha antes de enviar el formulario.");
        }

        // Validar dirección MAC (solo si se ingresa)
        if (macInput.value && !macRegex.test(macInput.value)) {
            errores.push("Dirección MAC inválida. Formato esperado: XX:XX:XX:XX:XX:XX");
        }

        // Validar dirección IP (solo si se ingresa)
        if (ipInput.value && !ipRegex.test(ipInput.value)) {
            errores.push("Dirección IP inválida. Debe ser una IP válida.");
        }

        // Si hay errores, evitar envío y mostrar alertas
        if (errores.length > 0) {
            event.preventDefault();
            alert(errores.join("\n"));
        }
    });

    // Lo usamos para guardar el estado del container del NAs
    // Si está tildada la opción Sólo privadas
    // Si se seleccionó un NAS, lo desplegamos al combobox
    // Revisar si hay un estado guardado en localStorage
    if (localStorage.getItem("soloPrivadas") === "true") {
        soloPrivadasCheckbox.checked = true;
        nasContainer.style.display = "block";
        nasSelect.disabled = false;
    }

    // Detectar cambios en el checkbox y guardarlos en localStorage
    soloPrivadasCheckbox.addEventListener("change", function() {
        if (this.checked) {
            nasContainer.style.display = "block";
            nasSelect.disabled = false;
            localStorage.setItem("soloPrivadas", "true"); // Guardar estado
        } else {
            nasContainer.style.display = "none";
            nasSelect.disabled = true;
            localStorage.removeItem("soloPrivadas"); // Borrar estado
        }
    });    
    
});